@@ -2,12 +2,10 @@
 
 """ Script to illustrate how to retrieve a user from the Duo Admin API using the associated email address"""
 
-from __future__ import absolute_import, print_function
 import sys
 import getpass
 
 import duo_client
-from six.moves import input
 
 argv_iter = iter(sys.argv[1:])
 
