@@ -43,10 +43,10 @@ class TestAdmin(unittest.TestCase):
         self.client_dtm._connect = \
             lambda: util.MockHTTPConnection(data_response_from_get_dtm_events=True)
 
-        self.client_activity = duo_client.admin.Admin(
+        self.items_response_client = duo_client.admin.Admin(
             'test_ikey', 'test_akey', 'example.com')
-        self.client_activity.account_id = 'DA012345678901234567'
-        self.client_activity._connect = \
+        self.items_response_client.account_id = 'DA012345678901234567'
+        self.items_response_client._connect = \
             lambda: util.MockHTTPConnection(data_response_from_get_items=True)
 
 
