@@ -17,9 +17,10 @@ class TestPassport(TestAdmin):
     def test_update_passport(self):
         """ Test update passport configuration
         """
-        response = self.client.update_passport_config(enabled_status="enabled-for-groups", enabled_groups=["passport-test-group"])
+        response = self.client.update_passport_config(enabled_status="enabled-for-groups", enabled_groups=["passport-test-group"], custom_supported_browsers={"macos": [{"team_id": "UBF8T346G9"},], "windows": [{"common_name": "Duo Security LLC"},],})
         self.assertEqual(response["uri"], "/admin/v2/passport/config")
         body = json.loads(response["body"])
         self.assertEqual(body["enabled_status"], "enabled-for-groups")
         self.assertEqual(body["enabled_groups"], ["passport-test-group"])
-        self.assertEqual(body["disabled_groups"], [])
+        self.assertEqual(body["disabled_groups"], None)
+        self.assertEqual(body["custom_supported_browsers"], {"macos":[{"team_id":"UBF8T346G9"}],"windows":[{"common_name":"Duo Security LLC"}]})
